Control Panel » KENZY.Ai [__APP_VERSION__]

KENZY.Ai Command Center

# Dashboard

- Last 5 (or 10) heard messages (Listener)
- Last 5 (or 10) spoken messages (Speaker)
- Who is in which room (Watcher)
- Send Global Message (Speaker ... perhaps with room selector?)
- Device buttons to start/stop

Column 1
Column 2
Column 1
Column 2
Column 1
Column 2
Column 1
Column 2

# Cameras

TEST

# Devices

Type / Container
Nickname / Group
Version
Accepts
kenzy.devices.Listener
http://localhost:8080
My Microphone
Living Room
0.9.2

- start
- stop
- audioOutStart
- audioOutEnd

kenzy.devices.Listener
http://localhost:8080
My Microphone
Living Room
0.9.2

- start
- stop

# Skills

Column 1
Column 2
Column 1
Column 2
Column 1
Column 2
Column 1
Column 2

# Actions

Show Log Word Wrap

Request
Column 1
Response
Column 1

# Logs

Column 1
Column 2
Column 1
Column 2
Column 1
Column 2
Column 1
Column 2

# Updates

TEST

# About

Kenzy is a foundation of Python code that enables hardware interactions leveraging Machine Learning to create Artificial Intelligence. Wow, that's a mouthful. Let's try again, Kenzy is a set of Python classes and functions that you can use to build your own personal assistant similar to Apple's Siri, Google's Assistant, or Amazon's Alexa. There are libraries for speech recognition, speech synthesis, face and object detection, and even face recognition. So basically Kenzy can see you, hear you, and respond to you.

Kenzy is 100% customizable. Its modular design allows you to create your own skills or integrate new hardware to fit your specific needs. The code is open source and shared with a business-friendly license.

## What Should You Expect?

Kenzy's main goal is to share knowledge and grow organically based on feedback and support from people like you. On the project web site, the github project, and within each of Kenzy's code modules you will find lots of documentation, examples, sample code, and other artifacts to help you grow in your own experience with Ai/ML and coding.

## Who Built Me

Kenzy was originally designed by @lnxusr1 during the Covid-19 lockdown in 2020.